==> node-server-0.0.4.tgz: package/lib/Application.js <==
var Net = require("net");
var Dns = require("dns");
var Os = require("os");
var Exit = require("./Exit.js").Exit;
var BootConfigManager = require("./BootConfigManager.js").BootConfigManager;
var LogConsole = require("./LogConsole.js").LogConsole;

exports.Application = function(configuration){
    this.configuration = configuration;
    this.location = null;
    this.resolvedHost = "127.0.0.1";
    this.mode = 'master';
    this.debug = false;
    this.pid = process.pid;
    //
    this.bootConfig = new BootConfigManager();
    //
    this.run = function(){
        var server;
        if(this.mode == 'master' && this.debug){
            //debug dev mode
            server = this._createServer();
            server.listen(this.location.port, this.location.host);
            console.info("Server: " + configuration.servicename + " started at location "  + this.location.host + ":" + this.location.port + ". Process id: " + this.pid + ".");
            var wasExit = false;
            var onExitFunction = function () {
                if(!wasExit){
                    console.info("Server: " + configuration.servicename + " [Process id: " + this.pid + "] Stopped.");
                    wasExit = true;
                    process.exit();
                }
            }
            process.on('exit', onExitFunction);
            process.on('SIGINT', onExitFunction);
            process.on('SIGTERM', onExitFunction);
            
            process.on('uncaughtException', function(err){
                console.error('emerg', err);
            });
            
            //TODO file changes watcher
        }
        else if(this.mode == 'slave'){
            //slave mode
            var stdin = new Net.Stream(0, 'unix');
            var that = this;   
            this.getInstanceId( function(id){
                process.title = "Node Server App: " + configuration.servicename + " Ver: " + configuration.version + " Instance: " + id;
                //zmieniamy console na logowanie do sysloga
                console = new LogConsole(configuration.servicename, id, configuration.version);                    
                console.info("Starting server: " + configuration.servicename + " at " + that.location.host + ":" + that.location.port);
                //czekamy na fd od mastera
                stdin.addListener('fd', function(fd) {
                    that._createServer(function(server){
                        server.listenFD(fd, 'tcp4');
                        process.stdout.write("{\"result\": {\"instance\": \"" + id + "\", \"pid\": " + that.pid + "}}\n");                    
                        //Odkladamy do sysloga start aplikacji
                        console.info("Server: " + configuration.servicename + " started at location "  + that.location.host + ":" + that.location.port + ". Process id: " + that.pid + ". Instance id: " + id);
                        
                        //jeśli proces zemrzy to wywalamy info o num z bootstrap.js
                        var wasExit = false;
                        var onExitFunction = function () {
                            if(!wasExit){
                                that.bootConfig.removeApplicationInfo(process.cwd(), that.pid);
                                that.bootConfig.save();
                                console.info("Server: " + configuration.servicename + " [Process id: " + that.pid + ", Instance id: " + id + "] Stopped.");
                                wasExit = true;
                                process.exit();
                            }
                        }
                        process.on('exit', onExitFunction);
                        process.on('SIGINT', onExitFunction);
                        process.on('SIGTERM', onExitFunction);
                        process.on('uncaughtException', function(err){
                            console.error('emerg', err);
                        });
                    });
                });
                stdin.resume(); 
            });
        }
    };
    this.getInstanceId = function(callback){
        //Rozwiązujemy nazwe hosta
        var that = this;
        Dns.getHostByName(Os.hostname(), function(err, ips){
            var resolvedIp = "127.0.0.1";
            if(!err){
                resolvedIp = ips[0]   
            };
            var parts = resolvedIp.split(".");
            for(var i=0; i < parts.length; i++){
                parts[i] = (1e15 + parseInt(parts[i],10).toString(16)).slice(-2);
            }
            parts = parts.join();
            parts = parseInt(parts, 16);
            parts = parseInt(parts, 10).toString(16);
            
            var time = parseInt(Date.now(), 16);
            
            var pid = parseInt(that.pid, 16);
            
            rand = parseInt(Math.random() * 10000, 16);
            callback(parts + "-" + time + "-" + pid + "-" + rand);
        }); 
    };
    this._createServer = function(callback){
        try{            
            var serverClass = require(configuration.handler.moduleName)[configuration.handler.className];
            var server = this._checkServer(new serverClass());
            callback(server);   
        }
        catch(err){
            Exit.applicationError(3001, "Problem running server class. Throwed error: " + err);   
        }
    };
    this._checkServer = function(server){
        if(typeof(server["listen"]) != "function"  || typeof(server["listenFD"]) != "function"){
            Exit.applicationError(3002, "Invalid application interface.");
        }
        return server;  
    };
};

==> node-server-0.0.6.tgz: package/lib/Application.js <==
var Net = require("net");
var Dns = require("dns");
var Os = require("os");
var Exit = require("./Exit.js").Exit;
var BootConfigManager = require("./BootConfigManager.js").BootConfigManager;
var LogConsole = require("./LogConsole.js").LogConsole;

exports.Application = function(configuration){
    this.configuration = configuration;
    this.location = null;
    this.resolvedHost = "127.0.0.1";
    this.mode = 'master';
    this.debug = false;
    this.pid = process.pid;
    //
    this.bootConfig = new BootConfigManager();
    //
    this.run = function(){
        var that = this;  
        if(this.mode == 'master' && this.debug){
            //debug dev mode
            this._createServer(function(server){
                server.listen(that.location.port, that.location.host);
                console.info("Server: " + configuration.servicename + " started at location "  + that.location.host + ":" + that.location.port + ". Process id: " + that.pid + ".");
                var wasExit = false;
                var onExitFunction = function () {
                    if(!wasExit){
                        console.info("Server: " + configuration.servicename + " [Process id: " + that.pid + "] Stopped.");
                        wasExit = true;
                        process.exit();
                    }
                }
                process.on('exit', onExitFunction);
                process.on('SIGINT', onExitFunction);
                process.on('SIGTERM', onExitFunction);
                
                process.on('uncaughtException', function(err){
                    console.error('emerg', err);
                }); 
            });
            
            //TODO file changes watcher
        }
        else if(this.mode == 'slave'){
            //slave mode
            var stdin = new Net.Stream(0, 'unix'); 
            this.getInstanceId( function(id){
                process.title = "Node Server App: " + configuration.servicename + " Ver: " + configuration.version + " Instance: " + id;
                //zmieniamy console na logowanie do sysloga
                console = new LogConsole(configuration.servicename, id, configuration.version);                    
                console.info("Starting server: " + configuration.servicename + " at " + that.location.host + ":" + that.location.port);
                //czekamy na fd od mastera
                stdin.addListener('fd', function(fd) {
                    that._createServer(function(server){
                        server.listenFD(fd, 'tcp4');
                        process.stdout.write("{\"result\": {\"instance\": \"" + id + "\", \"pid\": " + that.pid + "}}\n");                    
                        //Odkladamy do sysloga start aplikacji
                        console.info("Server: " + configuration.servicename + " started at location "  + that.location.host + ":" + that.location.port + ". Process id: " + that.pid + ". Instance id: " + id);
                        
                        //jeśli proces zemrzy to wywalamy info o num z bootstrap.js
                        var wasExit = false;
                        var onExitFunction = function () {
                            if(!wasExit){
                                that.bootConfig.removeApplicationInfo(process.cwd(), that.pid);
                                that.bootConfig.save();
                                console.info("Server: " + configuration.servicename + " [Process id: " + that.pid + ", Instance id: " + id + "] Stopped.");
                                wasExit = true;
                                process.exit();
                            }
                        }
                        process.on('exit', onExitFunction);
                        process.on('SIGINT', onExitFunction);
                        process.on('SIGTERM', onExitFunction);
                        process.on('uncaughtException', function(err){
                            console.error('emerg', err);
                        });
                    });
                });
                stdin.resume(); 
            });
        }
    };
    this.getInstanceId = function(callback){
        //Rozwiązujemy nazwe hosta
        var that = this;
        Dns.getHostByName(Os.hostname(), function(err, ips){
            var resolvedIp = "127.0.0.1";
            if(!err){
                resolvedIp = ips[0]   
            };
            var parts = resolvedIp.split(".");
            for(var i=0; i < parts.length; i++){
                parts[i] = (1e15 + parseInt(parts[i],10).toString(16)).slice(-2);
            }
            parts = parts.join();
            parts = parseInt(parts, 16);
            parts = parseInt(parts, 10).toString(16);
            
            var time = parseInt(Date.now(), 16);
            
            var pid = parseInt(that.pid, 16);
            
            rand = parseInt(Math.random() * 10000, 16);
            callback(parts + "-" + time + "-" + pid + "-" + rand);
        }); 
    };
    this._createServer = function(callback){
        try{            
            var serverClass = require(configuration.handler.moduleName)[configuration.handler.className];
            var server = this._checkServer(new serverClass());
            callback(server);   
        }
        catch(err){
            Exit.applicationError(3001, "Problem running server class. Throwed error: " + err);   
        }
    };
    this._checkServer = function(server){
        if(typeof(server["listen"]) != "function"  || typeof(server["listenFD"]) != "function"){
            Exit.applicationError(3002, "Invalid application interface.");
        }
        return server;  
    };
};
